unit neworder;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, Grids;

type
  TfrmNewOrder = class(TForm)
    GroupBox1: TGroupBox;
    Label1: TLabel;
    cbxSymbols: TComboBox;
    Label2: TLabel;
    cbxLots: TComboBox;
    Label3: TLabel;
    edtSL: TEdit;
    Label4: TLabel;
    edtTP: TEdit;
    GroupBox2: TGroupBox;
    Bevel1: TBevel;
    lblBidAsk: TLabel;
    btnSell: TButton;
    btnRequest: TButton;
    btnBuy: TButton;
    GroupBox3: TGroupBox;
    Label5: TLabel;
    cbxTypePendingOrder: TComboBox;
    Label6: TLabel;
    edtPrice: TEdit;
    btnSend: TButton;
    Timer1: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure btnRequestClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure btnSellClick(Sender: TObject);
    procedure btnBuyClick(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure btnSendClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure cbxSymbolsChange(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmNewOrder: TfrmNewOrder;
  ask,bid:double;
  donShowLiveQuotes:boolean;

implementation

{$R *.DFM}
uses MetaTraderAPI, main;
var   Hsocket:integer;
      t:integer;

procedure TfrmNewOrder.FormCreate(Sender: TObject);
begin
   cbxLots.ItemIndex:=3;
   cbxTypePendingOrder.ItemIndex:=0;
   HSocket:=-1;
end;

procedure TfrmNewOrder.btnRequestClick(Sender: TObject);
var
  error:integer;
begin
    error:=MTAPI.GetPrices(HSocket,pchar(cbxSymbols.Text),round(100*StrToFloat(cbxLots.text)),@bid,@ask);
    if error<>RET_OK then lblBidAsk.Caption:=MTApi.GetErrorDescription(error)
    else lblBidAsk.Caption:=FloatToStrF(bid,fffixed,10,4)+'/'+FloatToStrF(ask,fffixed,10,4);
    btnRequest.Enabled:=false;
    btnSell.Enabled:=true;
    btnBuy.Enabled:=true;
    t:=5;
    Timer1.Enabled:=true;
end;

procedure TfrmNewOrder.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  if HSocket>-1 then main.frmMain.disconnect(HSocket);
  HSocket:=-1;
  lblBidAsk.Caption:='Please Request';
  btnRequest.Enabled:=true;
  btnSell.Enabled:=false;
  btnBuy.Enabled:=false;
  Timer1.Enabled:=false;
  edtTP.text:='';
  edtSL.text:='';
end;

procedure TfrmNewOrder.btnSellClick(Sender: TObject);
var soi:TSendOrderInfo;
    error:integer;
begin
  Timer1.Enabled:=false;
  FillChar(soi,SizeOf(TSendOrderInfo),#0);
  strCopy(soi.symbol,pchar(cbxSymbols.text));
  soi.cmd:=OP_SELL;
  soi.volume:=round(100*StrToFloat(cbxLots.text));
  soi.price:=bid;
  try
    soi.tp:=StrToFloat(edtTP.text);
  except
    soi.tp:=0;
  end;
  try
    soi.sl:=StrToFloat(edtSL.text);
  except
    soi.sl:=0;
  end;
  error:=MTApi.SendOrder(HSocket,@soi);
  donShowLiveQuotes:=true;
  if error<>RET_OK
  then lblBidAsk.caption:=MTApi.GetErrorDescription(error)
  else close;
end;

procedure TfrmNewOrder.btnBuyClick(Sender: TObject);
var soi:TSendOrderInfo;
    error:integer;
begin
  Timer1.Enabled:=false;
  FillChar(soi,SizeOf(TSendOrderInfo),#0);
  strCopy(soi.symbol,pchar(cbxSymbols.text));
  soi.cmd:=OP_BUY;
  soi.volume:=round(100*StrToFloat(cbxLots.text));
  soi.price:=ask;
  try
    soi.tp:=StrToFloat(edtTP.text);
  except
    soi.tp:=0;
  end;
  try
    soi.sl:=StrToFloat(edtSL.text);
  except
    soi.sl:=0;
  end;
  error:=MTApi.SendOrder(HSocket,@soi);
  donShowLiveQuotes:=true;
  if error<>RET_OK
  then lblBidAsk.caption:=MTApi.GetErrorDescription(error)
  else close;
end;

procedure TfrmNewOrder.Timer1Timer(Sender: TObject);
begin
  if t>0 then GroupBox2.Caption:='Market Order    '+intToStr(t) else
    begin
       GroupBox2.Caption:='Market Order';
       Timer1.Enabled:=false;
       btnSell.Enabled:=false;
       btnBuy.Enabled:=false;
    end;
  t:=t-1;
end;

procedure TfrmNewOrder.btnSendClick(Sender: TObject);
var soi:TSendOrderInfo;
    error:integer;
begin
  HSocket:=main.frmMain.connect(main.server,main.port);
  error:=MTApi.Login(HSocket,main.login,main.password);
  if error<>RET_OK
  then ShowMessage(' .  : '+MTApi.GetErrorDescription(error));
  //  
  FillChar(soi,SizeOf(TSendOrderInfo),#0);
  strCopy(soi.symbol,pchar(cbxSymbols.text));
  case cbxTypePendingOrder.itemIndex of
    0:soi.cmd:=OP_BUY_LIMIT;
    1:soi.cmd:=OP_BUY_STOP;
    2:soi.cmd:=OP_SELL_LIMIT;
    3:soi.cmd:=OP_SELL_STOP;
  end;
  soi.volume:=round(100*StrToFloat(cbxLots.text));
  soi.price:=StrToFloat(edtPrice.text);
  try
    soi.tp:=StrToFloat(edtTP.text);
  except
    soi.tp:=0;
  end;
  try
    soi.sl:=StrToFloat(edtSL.text);
  except
    soi.sl:=0;
  end;
  error:=MTApi.SendOrder(HSocket,@soi);
  if error<>RET_OK
  then
    lblBidAsk.caption:=MTApi.GetErrorDescription(error)
  else
    close;
end;

procedure TfrmNewOrder.FormShow(Sender: TObject);
var error:integer;
begin
  HSocket:=main.frmMain.connect(main.server,main.port);
  error:=MTApi.Login(HSocket,main.login,main.password);
  if error<>RET_OK
  then ShowMessage(' .  : '+MTApi.GetErrorDescription(error));
  if Symbols_exemode[cbxSymbols.ItemIndex]=EXE_REQUEST
  then
    begin
      btnSell.Enabled:=false;
      btnBuy.Enabled:=false;
      btnRequest.Enabled:=true;
    end
  else
    begin
      btnSell.Enabled:=true;
      btnBuy.Enabled:=true;
      btnRequest.Enabled:=false;
    end;
end;

procedure TfrmNewOrder.cbxSymbolsChange(Sender: TObject);
begin
  lblBidAsk.Caption:='Please Request';

  if Symbols_exemode[cbxSymbols.ItemIndex]=EXE_REQUEST
  then
    begin
      btnSell.Enabled:=false;
      btnBuy.Enabled:=false;
      btnRequest.Enabled:=true;
    end
  else
    begin
      btnSell.Enabled:=true;
      btnBuy.Enabled:=true;
      btnRequest.Enabled:=false;
    end;
end;

end.
